"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const core_1 = require("./core");
function getDisplayName(WrappedComponent) {
    return WrappedComponent.displayName || WrappedComponent.name || 'Component';
}
function isNextApiHandler(handler) {
    return handler.length > 1;
}
function withSession(handler, options) {
    // API Routes
    if (isNextApiHandler(handler))
        return async function WithSession(req, res) {
            await core_1.applySession(req, res, options);
            return handler(req, res);
        };
    // Pages
    const Page = handler;
    function WithSession(props) {
        return react_1.createElement(Page, props);
    }
    WithSession.displayName = `withSession(${getDisplayName(Page)})`;
    if (Page.getInitialProps) {
        WithSession.getInitialProps = async (pageCtx) => {
            if (typeof window === 'undefined') {
                await core_1.applySession(pageCtx.req, pageCtx.res, options);
            }
            return Page.getInitialProps(pageCtx);
        };
    }
    return WithSession;
}
exports.default = withSession;
